RefreshKind

Struct RefreshKind 

pub struct RefreshKind { /* private fields */ }
Used to determine what you want to refresh specifically on the System type.

⚠️ Just like all other refresh types, ruling out a refresh doesn’t assure you that the information won’t be retrieved if the information is accessible without needing extra computation.

use sysinfo::{RefreshKind, System};

// We want everything except memory.
let mut system = System::new_with_specifics(RefreshKind::everything().without_memory());

assert_eq!(system.total_memory(), 0);
assert!(system.processes().len() > 0);

Implementations

Source

impl RefreshKind

pub fn nothing() -> Self

Creates a new RefreshKind with every refresh set to false/None.

use sysinfo::RefreshKind;

let r = RefreshKind::nothing();

assert_eq!(r.processes().is_some(), false);
assert_eq!(r.memory().is_some(), false);
assert_eq!(r.cpu().is_some(), false);
pub fn everything() -> Self

Creates a new RefreshKind with every refresh set to true/Some(...).

use sysinfo::RefreshKind;

let r = RefreshKind::everything();

assert_eq!(r.processes().is_some(), true);
assert_eq!(r.memory().is_some(), true);
assert_eq!(r.cpu().is_some(), true);
pub fn processes(&self) -> Option<ProcessRefreshKind>

Returns the value of the “processes” refresh kind.

use sysinfo::{RefreshKind, ProcessRefreshKind};

let r = RefreshKind::nothing();
assert_eq!(r.processes().is_some(), false);

let r = r.with_processes(ProcessRefreshKind::everything());
assert_eq!(r.processes().is_some(), true);

let r = r.without_processes();
assert_eq!(r.processes().is_some(), false);
pub fn with_processes(self, kind: ProcessRefreshKind) -> Self

Sets the value of the “processes” refresh kind to Some(...).

use sysinfo::{RefreshKind, ProcessRefreshKind};

let r = RefreshKind::nothing();
assert_eq!(r.processes().is_some(), false);

let r = r.with_processes(ProcessRefreshKind::everything());
assert_eq!(r.processes().is_some(), true);
pub fn without_processes(self) -> Self

Sets the value of the “processes” refresh kind to None.

use sysinfo::RefreshKind;

let r = RefreshKind::everything();
assert_eq!(r.processes().is_some(), true);

let r = r.without_processes();
assert_eq!(r.processes().is_some(), false);
pub fn memory(&self) -> Option<MemoryRefreshKind>

Returns the value of the “memory” refresh kind.

use sysinfo::{RefreshKind, MemoryRefreshKind};

let r = RefreshKind::nothing();
assert_eq!(r.memory().is_some(), false);

let r = r.with_memory(MemoryRefreshKind::everything());
assert_eq!(r.memory().is_some(), true);

let r = r.without_memory();
assert_eq!(r.memory().is_some(), false);
pub fn with_memory(self, kind: MemoryRefreshKind) -> Self

Sets the value of the “memory” refresh kind to Some(...).

use sysinfo::{RefreshKind, MemoryRefreshKind};

let r = RefreshKind::nothing();
assert_eq!(r.memory().is_some(), false);

let r = r.with_memory(MemoryRefreshKind::everything());
assert_eq!(r.memory().is_some(), true);
pub fn without_memory(self) -> Self

Sets the value of the “memory” refresh kind to None.

use sysinfo::RefreshKind;

let r = RefreshKind::everything();
assert_eq!(r.memory().is_some(), true);

let r = r.without_memory();
assert_eq!(r.memory().is_some(), false);
pub fn cpu(&self) -> Option<CpuRefreshKind>

Returns the value of the “cpu” refresh kind.

use sysinfo::{RefreshKind, CpuRefreshKind};

let r = RefreshKind::nothing();
assert_eq!(r.cpu().is_some(), false);

let r = r.with_cpu(CpuRefreshKind::everything());
assert_eq!(r.cpu().is_some(), true);

let r = r.without_cpu();
assert_eq!(r.cpu().is_some(), false);
pub fn with_cpu(self, kind: CpuRefreshKind) -> Self

Sets the value of the “cpu” refresh kind to Some(...).

use sysinfo::{RefreshKind, CpuRefreshKind};

let r = RefreshKind::nothing();
assert_eq!(r.cpu().is_some(), false);

let r = r.with_cpu(CpuRefreshKind::everything());
assert_eq!(r.cpu().is_some(), true);
pub fn without_cpu(self) -> Self

Sets the value of the “cpu” refresh kind to None.

use sysinfo::RefreshKind;

let r = RefreshKind::everything();
assert_eq!(r.cpu().is_some(), true);

let r = r.without_cpu();
assert_eq!(r.cpu().is_some(), false);